Crate relm_state [−] [src]
This crate provide the non-GUI part of relm: Basic component and message connection methods.
Macros
| connect |
Connect events to sending a message. |
| connect_async |
Connect an asynchronous method call to send a message.
The variants with |
| connect_async_full |
Like |
| connect_async_func |
Connect an asynchronous function call to send a message.
The variants with |
| connect_async_func_full |
Like |
| connect_stream |
Connect events to sending a message.
Similar to |
Structs
| EventStream |
A stream of messages to be used for widget/signal communication and inter-widget communication. |
| Relm |
Handle event stream to send messages to the |
Traits
| DisplayVariant |
Format trait for enum variants. |
| Update |
Trait for a basic (non-widget) component.
A component has a model (data) associated with it and can mutate it when it receives a message
(in the |
| UpdateNew |
Trait for an |
Functions
| execute |
Create a bare component, i.e. a component only implementing the Update trait, not the Widget trait. |
| init_component |
Initialize a component by creating its subscriptions and dispatching the messages from the stream. |