[−][src]Macro relm_state::connect
Connect events to sending a message.
Rules
-
Send
$msgto$other_componentwhen the GTK+$eventis emitted on$widget. -
Optionally send
$msg.0when the GTK+$eventis emitted on$widget. Return$msg.1in the GTK+ callback. This variant gives more control to the caller since it expects a$msgreturning(Option<MSG>, ReturnValue)where theReturnValueis the value to return in the GTK+ callback. Optioncan be None if no message needs to be emitted. -
Send
$msgwhen the GTK+$eventis emitted on$widget. -
Send
$msgto$widgetwhen the$messageis received on$stream.